import { useMemo } from "react";
import { useSession } from "../lib/store";

export function Scoreboard() {
    const session = useSession();
    const sortedKeys = useMemo(() => {
        const nKeys = Object.keys(session.scoreboard);
        nKeys.sort((a, b) => session.scoreboard[b] - session.scoreboard[a]);
        return nKeys;
    }, [session.scoreboard]);

    if (sortedKeys.length === 0) return <></>;

    return <div className='p-5'>
        <h1 className='pb-5'> Scoreboard </h1>
        <div className="flex justify-center p-3">
            <div className="border-white/20 border border-solid rounded-lg">
                <table className="">
                    <thead>
                        <tr className="text-xl">
                            <th className="p-2 px-5 bg-white/30 rounded-tl-lg">
                                Player
                            </th>
                            <th className="p-2 px-5 bg-white/30 rounded-tr-lg">
                                No. Wins
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        {sortedKeys.map((a, i) =>
                            <tr key={a}>
                                <td className={`p-2 px-5 ${i === 0 ? 'text-xl font-bold' : ''}`}>
                                    {a}
                                </td>
                                <td className={`p-2 px-5 ${i === 0 ? 'text-xl font-bold' : ''}`}>
                                    {session.scoreboard[a]}
                                </td>
                            </tr>
                        )}
                    </tbody>
                </table>
            </div>
        </div>
    </div>
}
